@@ -6,7 +6,7 @@ use strict;
 use warnings;
 use Carp 'croak';
 
-our $VERSION = '1.01'; # VERSION
+our $VERSION = '1.02'; # VERSION
 
 my $duration_element_re = qr/(?<expr>[-+*\/\d]+)\s*(?<unit>[A-z]+)\s*/;
 
@@ -187,6 +187,7 @@ sub _parse_table {
 sub _parse_duration {
     my ( $self, $duration, $units ) = @_;
 
+    $duration //= '';
     $duration =~ s/(\d+)\s*:\s*(\d+)(?:\s*:\s*(\d+))?/
         $1 . 'h' . $2 . 'm' . ( ($3) ? $3 . 's' : '' )
     /ge;
@@ -332,7 +333,7 @@ Unit::Duration - Work-time unit duration conversion and canonicalization
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =for markdown [![test](https://github.com/gryphonshafer/Unit-Duration/workflows/test/badge.svg)](https://github.com/gryphonshafer/Unit-Duration/actions?query=workflow%3Atest)
 [![codecov](https://codecov.io/gh/gryphonshafer/Unit-Duration/graph/badge.svg)](https://codecov.io/gh/gryphonshafer/Unit-Duration)
@@ -412,7 +413,7 @@ version 1.01
             unit_type   => 'short',
             compress    => 0,
         },
-        'default', # table name or $table string or table structure
+        'default', # table name or table string or table structure
     );
 
     my $hours_by_table = $ud->sum_as( hours => '2 days -6h', 'default' );
@@ -457,9 +458,9 @@ define the unit's duration relative to some lower unit. Ultimately, there needs
 to be 1 and only 1 unit that is the "base" unit. In the default table, this is
 "second".
 
-For tables in string form, the separation of columns can be done using any non-
-digit, non-letter character other than commas and semicolons. All spacing is
-ignored. Tables in data form are an arrayref of hashrefs where each hashref
+For tables in string form, the separation of columns can be done using any
+non-digit, non-letter character other than commas and semicolons. All spacing
+is ignored. Tables in data form are an arrayref of hashrefs where each hashref
 contains C<letter>, C<short>, optionally a C<long>, and a C<duration>.
 
     {
@@ -511,7 +512,7 @@ string based on the settings and table used.
 It can optionally can accept settings overrides in a hashref. See
 L</"SETTINGS"> below.
 
-    my $y = $ud->canonicalize('4d 6h 4d 3h', { compress => 1 } );
+    my $y = $ud->canonicalize( '4d 6h 4d 3h', { compress => 1 } );
     # $y eq '1 wk, 4 days, 1 hr'
 
     my $z = $ud->canonicalize(
@@ -537,7 +538,7 @@ structure.
             unit_type   => 'short',
             compress    => 0,
         },
-        'default', # table name or $table string or table structure
+        'default', # table name or table string or table structure
     );
 
 =head2 sum_as
@@ -628,7 +629,7 @@ example:
 By setting C<compress> to a true value, C<canonicalize> will shift values
 between units. For example:
 
-    my $y = $ud->canonicalize('4d 6h 4d 3h', { compress => 1 } );
+    my $y = $ud->canonicalize( '4d 6h 4d 3h', { compress => 1 } );
     # $y eq '1 week, 2 days, 1 hrs'
 
 =head1 SEE ALSO
